<?php

use Firebase\JWT\JWK;
use Firebase\JWT\JWT;
use Xamax\Wordpress\XamaxPayment;

function getIconAndLabelForCurrency(string $currency): array {
	switch (strtolower($currency)) {
		case 'usdt':
			return [
				'network'  => 'ETHEREUM',
				'priority' => 0,
				'label'    => 'USDT (ERC-20)',
				'icon'     => XAMAX_PAYMENT_PLUGIN_URL . '/assets/images/currencies/usdt_erc20.svg'
			];
		case 'usdt_trc20':
			return [
				'network'  => 'TRON',
				'priority' => 2,
				'label'    => 'USDT (TRC-20)',
				'icon'     => XAMAX_PAYMENT_PLUGIN_URL . '/assets/images/currencies/usdt_trc20.svg'
			];
		case 'btc':
			return [
				'network'  => 'BITCOIN',
				'priority' => 3,
				'label'    => 'BITCOIN',
				'icon'     => XAMAX_PAYMENT_PLUGIN_URL . '/assets/images/currencies/btc.svg'
			];
		case 'eth':
			return [
				'network'  => 'ETHEREUM',
				'priority' => 4,
				'label'    => 'ETHEREUM',
				'icon'     => XAMAX_PAYMENT_PLUGIN_URL . '/assets/images/currencies/eth.svg'
			];
		case 'bscusd':
			return [
				'network'  => 'BINANCE SMART CHAIN',
				'priority' => 5,
				'label'    => 'USDT (BEP-20)',
				'icon'     => XAMAX_PAYMENT_PLUGIN_URL . '/assets/images/currencies/usdt_bep20.svg'
			];
		case 'busd':
			return [
				'network'  => 'Binance Smart Chain',
				'priority' => 6,
				'label'    => 'BUSD (BEP-20)',
				'icon'     => XAMAX_PAYMENT_PLUGIN_URL . '/assets/images/currencies/busd_bep20.svg'
			];
		case 'bnb':
			return [
				'network'  => 'Binance Smart Chain',
				'priority' => 7,
				'label'    => 'BINANCE COIN',
				'icon'     => XAMAX_PAYMENT_PLUGIN_URL . '/assets/images/currencies/bnb.svg'
			];
		case 'usdc':
			return [
				'network'  => 'ETHEREUM',
				'priority' => 8,
				'label'    => 'USDC (ERC-20)',
				'icon'     => XAMAX_PAYMENT_PLUGIN_URL . '/assets/images/currencies/usdc_erc20.svg'
			];
		case 'bch':
			return [
				'network'  => 'BITCOIN CASH',
				'priority' => 9,
				'label'    => 'BITCOIN CASH',
				'icon'     => XAMAX_PAYMENT_PLUGIN_URL . '/assets/images/currencies/bch.svg'
			];
		case 'ltc':
			return [
				'network'  => 'LITECOIN',
				'priority' => 10,
				'label'    => 'LITECOIN',
				'icon'     => XAMAX_PAYMENT_PLUGIN_URL . '/assets/images/currencies/ltc.svg'
			];
		case 'qtum':
			return [
				'network'  => 'QTUM',
				'priority' => 11,
				'label'    => 'QTUM',
				'icon'     => XAMAX_PAYMENT_PLUGIN_URL . '/assets/images/currencies/qtum.svg'
			];
		case 'zec':
			return [
				'network'  => 'ZEC',
				'priority' => 12,
				'label'    => 'ZEC',
				'icon'     => XAMAX_PAYMENT_PLUGIN_URL . '/assets/images/currencies/zec.svg'
			];
		case 'trx':
			return [
				'network'  => 'TRON',
				'priority' => 13,
				'label'    => 'TRON',
				'icon'     => XAMAX_PAYMENT_PLUGIN_URL . '/assets/images/currencies/trx.svg'
			];
		case 'bsc':
			return [
				'network'  => 'BINANCE SMART CHAIN',
				'priority' => 14,
				'label'    => 'BINANCE SMART CHAIN',
				'icon'     => XAMAX_PAYMENT_PLUGIN_URL . '/assets/images/currencies/bsc.svg'
			];
		case 'btg':
			return [
				'network'  => 'BITCOIN GOLD',
				'priority' => 15,
				'label'    => 'BITCOIN GOLD',
				'icon'     => XAMAX_PAYMENT_PLUGIN_URL . '/assets/images/currencies/btg.svg'
			];
		case 'dash':
			return [
				'network'  => 'DASH',
				'priority' => 16,
				'label'    => 'DASH',
				'icon'     => XAMAX_PAYMENT_PLUGIN_URL . '/assets/images/currencies/dash.svg'
			];
		default:
			return [
				'network'  => strtoupper($currency),
				'priority' => 17,
				'label'    => strtoupper($currency),
				'icon'     => XAMAX_PAYMENT_PLUGIN_URL . '/assets/images/currencies/default.png'
			];
	}
}

function sortByPriority($a, $b) {
	return $a['priority'] - $b['priority'];
}

/**
 * Validating headers
 *
 * @throws Exception
 */
function validateHeaderBearer($requestAuthorizationHeader, array $requestBody, string $environment): bool {
	// Get JWK set from the environment
	$jwks = XamaxPayment::getOpenJwks($environment);
	$jwkSet = JWK::parseKeySet($jwks);

	// Strip 'Bearer ' from the header
	$requestAuthorizationHeader = str_replace('Bearer ', '', $requestAuthorizationHeader);

	// Initialize the headers variable
	$headers = new stdClass();

	// Decode the JWT to extract the headers and claims
	try {
		$decodedPayload = JWT::decode($requestAuthorizationHeader, $jwkSet, $headers);
	} catch (Exception $e) {
		return false;
	}

	$claims = (array) $decodedPayload;

	// Check body hash
	if (hash($claims['body_hash_method'], json_encode($requestBody)) != $claims['body_hash']) {
		throw new Exception('Incorrect body checksum');
	}

	// Check available key
	$kid = $headers->kid ?? null;
	if (!$kid) {
		return false;
	}

	$keyToUse = $jwkSet[$kid] ?? null;
	if (!$keyToUse) {
		return false; // JWKS keys outdated
	}

	// Verify JWT signature
	try {
		JWT::decode($requestAuthorizationHeader, [$kid => $keyToUse], $headers);
	} catch (Exception $e) {
		return false;
	}

	return true;
}

function render(string $path, array $params = []): string {
	extract($params);
	require_once XAMAX_PAYMENT_PLUGIN_PATH . '/src/views/' . $path . '.php';
	return '';
}
