<?php

/**
 * Plugin Name: Xamax - WooCommerce Payment Gateway
 * Plugin URI:  https://www.xamax.io
 * Author:      Jasur Dustmurodov
 * Author URI:  https://www.github.com/dorsone
 * Description: Allows you to use Xamax payment gateway with the WooCommerce plugin.
 * Version:     1.0.0
 * License:     GPL-2.0+
 * License URL: http://www.gnu.org/licenses/gpl-2.0.txt
 * text-domain: xamax-payment
 */

use Automattic\WooCommerce\Utilities\FeaturesUtil;

if (!defined('ABSPATH')) {
	exit('You must not access this file directly');
}

define('XAMAX_PAYMENT_VERSION', '1.0.0');
define('XAMAX_PAYMENT_PLUGIN_URL', plugin_dir_url(__FILE__));
define('XAMAX_PAYMENT_PLUGIN_PATH', plugin_dir_path(__FILE__));
define('XAMAX_PAYMENT_TEXT_DOMAIN', 'xamax-payment');

// Checking if WooCommerce installed or not
if (
	!in_array(
		'woocommerce/woocommerce.php',
		apply_filters('active_plugins', get_option('active_plugins'))
	)
) {
	add_action('admin_notices', 'xamax_payment_woocommerce_notice');
	return;
} else {
// Register the Composer autoloader...
	require XAMAX_PAYMENT_PLUGIN_PATH . '/vendor/autoload.php';
	add_action('woocommerce_blocks_loaded', 'rudr_gateway_block_support');
	add_filter('woocommerce_payment_gateways', 'xamax_payment_gateway');
	add_action('plugins_loaded', 'xamax_payment_init');
	add_filter('plugin_action_links_' . plugin_basename(__FILE__), 'xamax_payment_settings_link');
	add_action('before_woocommerce_init', 'rudr_cart_checkout_blocks_compatibility');
	add_filter('woocommerce_currency_symbol', 'xamax_usd_currency_symbol', 10, 2);
	add_filter('woocommerce_currencies', 'xamax_usd_currency', 10, 1);
	require_once XAMAX_PAYMENT_PLUGIN_PATH . '/helpers.php';
}


function xamax_payment_init() {
	if (!class_exists('Xamax_Payment_Gateway')) {
		include_once XAMAX_PAYMENT_PLUGIN_PATH . '/includes/main-file.php';
	}
}

function xamax_payment_woocommerce_notice() {
	ob_start();

	require_once XAMAX_PAYMENT_PLUGIN_PATH . '/templates/admin_notice.php';

	$output = ob_get_clean();
	echo esc_html($output);
}

function xamax_payment_settings_link(array $links): array {
	$links[] = '<a href=\'admin.php?page=wc-settings&tab=checkout&section=xamax_payment\'>Settings</a>';

	return $links;
}

function xamax_payment_gateway(array $gateways): array {
	$gateways[] = 'Xamax_Payment_Gateway';

	return $gateways;
}

function rudr_gateway_block_support() {
// here we're including our 'gateway block support class'
	require_once XAMAX_PAYMENT_PLUGIN_PATH . '/includes/gateway-blocks-support.php';

// registering the PHP class we have just included
	add_action(
		'woocommerce_blocks_payment_method_type_registration',
		function (Automattic\WooCommerce\Blocks\Payments\PaymentMethodRegistry $payment_method_registry) {
			$payment_method_registry->register(new Xamax_Payment_Gateway_Blocks_Support());
		}
	);
}

function rudr_cart_checkout_blocks_compatibility() {
	if (class_exists('\Automattic\WooCommerce\Utilities\FeaturesUtil')) {
		FeaturesUtil::declare_compatibility(
			'cart_checkout_blocks',
			__FILE__,
			false // true (compatible, default) or false (not compatible)
		);
	}

}

/**
 * Add roubles in currencies
 *
 * @since 0.3
 */
function xamax_usd_currency_symbol($currency_symbol, $currency) {
	if ('USD' == $currency) {
		$currency_symbol = '$';
	}
	return $currency_symbol;
}

function xamax_usd_currency($currencies) {
	$currencies['USD'] = 'USA Dollar';
	return $currencies;
}
